.. aiorq documentation master file, created by
   sphinx-quickstart on Sun Nov 14 18:17:36 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to aiorq documentation!
======================================

.. toctree::
   :maxdepth: 4

   docs/index



